<%@ taglib uri="webwork" prefix="webwork" %>

<%@ page import="com.atlassian.jira.ManagerFactory,
                 org.ofbiz.core.entity.GenericValue,
                 com.atlassian.jira.web.SessionKeys,
                 com.opensymphony.user.UserManager,
                 com.opensymphony.user.User,
                 java.util.List,
                 com.atlassian.jira.issue.action.Worklog,
                 com.atlassian.core.ofbiz.CoreFactory,
                 org.ofbiz.core.util.UtilMisc,
                 com.atlassian.core.util.CacheUtils,
                 com.atlassian.jira.issue.history.ChangeLogUtils,
                 java.util.ArrayList,
                 com.atlassian.jira.issue.history.ChangeItemBean,
                 java.util.Locale,
                 com.atlassian.jira.config.properties.APKeys,
                 com.atlassian.core.util.DateUtils,
                 java.util.ResourceBundle,
                 com.atlassian.jira.web.action.JiraWebActionSupport"%>
<%!
    GenericValue getIssue(String key) throws Exception {
        GenericValue issue = ManagerFactory.getIssueManager().getIssue(key);
        if (issue == null) throw new RuntimeException("No issue with key '"+key+"'");
        return issue;
    }
    List getWorklogs(String key, HttpServletRequest request) throws Exception
    {
        User user = UserManager.getInstance().getUser(request.getRemoteUser());
        return ManagerFactory.getActionManager().getWorklog(getIssue(key), user);
    }
    Worklog getWorklog(String key, String action, HttpServletRequest request) throws Exception
    {
        for (int i = 0; i < getWorklogs(key, request).size(); i++)
        {
            Worklog worklog = (Worklog) getWorklogs(key, request).get(i);
            if (new Long(action).equals(worklog.getId()))
            {
                return worklog;
            }
        }
        throw new RuntimeException("No worklog on issue "+key+" with id "+action);
    }
    void updateWorklog(String key, String actionStr, String periodMins, HttpServletRequest request) throws Exception
    {
        GenericValue issue = getIssue(key);
        User user = UserManager.getInstance().getUser(request.getRemoteUser());
        Long action = new Long(actionStr);
        long period = new Long(periodMins).longValue()*60;
        List actions = CoreFactory.getGenericDelegator().findByAnd("Action", UtilMisc.toMap("id", action));
        if (actions.size() == 0) throw new RuntimeException("Could not find action with id "+action);
        GenericValue worklogGV = (GenericValue) actions.get(0);
        Long oldPeriod = worklogGV.getLong("numvalue");
        worklogGV.set("numvalue", new Long(period));
        worklogGV.store();


        long diff = period - oldPeriod.longValue();
        List changeItems = new ArrayList();
        adjustIssueField(issue, "timespent", diff, changeItems);
        adjustIssueField(issue, "timeestimate", -diff, changeItems);
        issue.store();
        ManagerFactory.getCacheManager().flushAll();

        ChangeLogUtils.createChangeGroup(user, issue, issue, changeItems, true);
    }
    void adjustIssueField(GenericValue issue, String field, long diff, List changeItems)
    {
        Long origTime = issue.getLong(field);
        Long timeSpent = origTime;
        System.out.println("Field "+field+": Adding "+diff+" to "+origTime);
        timeSpent = new Long(origTime.longValue() + diff);
        issue.set(field, timeSpent);
        changeItems.add(new ChangeItemBean(ChangeItemBean.STATIC_FIELD, field, ""+origTime, ""+timeSpent));
    }


    public String getPrettyDuration(Long duration, Locale locale)
    {
        int hoursPerDay = new Integer(ManagerFactory.getApplicationProperties().getDefaultBackedString(APKeys.JIRA_TIMETRACKING_HOURS_PER_DAY)).intValue();
        int daysPerWeek = new Integer(ManagerFactory.getApplicationProperties().getDefaultBackedString(APKeys.JIRA_TIMETRACKING_DAYS_PER_WEEK)).intValue();

        return DateUtils.getDurationPretty(duration.longValue(), hoursPerDay, daysPerWeek, getDefaultResourceBundle(locale));
    }

    private ResourceBundle getDefaultResourceBundle(Locale locale)
    {
        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
        return ResourceBundle.getBundle(JiraWebActionSupport.class.getName(), locale, classLoader);
    }

 %>
<html>
<body>
<h2><webwork:text name="'admin.editworklog.worklog.editor'"/></h2>
<p><webwork:text name="'admin.editworklog.page.description'">
    <webwork:param name="'value0'"><a href="http://jira.atlassian.com/browse/JRA-2411"></webwork:param>
    <webwork:param name="'value1'"></a></webwork:param>
</webwork:text></p>
<% try { %>
<%
    String key = request.getParameter("key");
    String action = request.getParameter("action");
    String period = request.getParameter("period");
    if (key != null && action != null && period != null) updateWorklog(key, action, period, request);
%>

<form>
<webwork:text name="'admin.editworklog.issue.key'"/>: <input name="key" value="<%=(key == null ? "" : key)%>" />
<% if (key != null) { %>
<h4><webwork:text name="'admin.editworklog.work.logs.for'">
    <webwork:param name="'value0'"><a href="<%=request.getContextPath()%>/browse/<%=key%>"><%=key%></a></webwork:param>
</webwork:text></h4>

<br><table border="1" cellpadding="5">
<tr><th><webwork:text name="'admin.editworklog.user'"/></th><th><webwork:text name="'admin.editworklog.time.spent'"/></th><th><webwork:text name="'admin.editworklog.comment'"/></th></tr>
<% for (int i = 0; i < getWorklogs(key, request).size(); i++)
{
    Worklog worklog = (Worklog) getWorklogs(key, request).get(i);
    out.println("<tr><td>"+worklog.getUsername()+"</td><td><a href=editworklog.jsp?key="+key+"&action="+worklog.getId()+">"+getPrettyDuration(worklog.getTimeSpent(), request.getLocale())+"</a></td><td>"+worklog.getComment()+"</td></tr>");
}
    %>
</table>
<p>
<% if (action != null) {
    if (period != null) { %>
        <webwork:text name="'admin.editworklog.worklog.updated.to'">
            <webwork:param name="'value0'"><%=getWorklog(key, action, request).getTimeSpent()%></webwork:param>
        </webwork:text>
    <% } else { %>
        <input name="key" type="hidden" value="<%= key %>" />
        <input name="action" type="hidden" value="<%= action %>" />
        <input name="oldperiod" type="hidden" value="<%=getWorklog(key, action, request).getTimeSpent()%>" />
        <webwork:text name="'admin.editworklog.enter.new.time.period'"/>: <input size="5" name="period" value="<%=getWorklog(key, action, request).getTimeSpent().longValue()/60%>" />
        <input type="submit" value="<webwork:text name="'common.forms.update'"/>">
    <% }
    }
    } %>
</form>

<% } catch (Throwable t) {
t.printStackTrace();
%>
<h3><font color="red"><webwork:text name="'common.words.error'"/>: <%=t%> </font></h3>
<p>
<% } %>
</body>
</html>
